@@ -4,7 +4,7 @@
 /*
  * enums: Definitions of enumerations and flags used in GObject objects
  * 
- * Copyrigt 2012-2016 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -131,31 +131,6 @@ GType xfdashboard_bindings_pool_error_enum_get_type(void)
 }
 
 
-/* enumerations from "button.h" */
-#include "button.h"
-
-GType xfdashboard_button_style_get_type(void)
-{
-	static volatile gsize	g_define_type_id__volatile=0;
-
-	if(g_once_init_enter(&g_define_type_id__volatile))
-	{
-		static const GEnumValue values[]=
-		{
-			{ XFDASHBOARD_BUTTON_STYLE_TEXT, "XFDASHBOARD_BUTTON_STYLE_TEXT", "text" },
-			{ XFDASHBOARD_BUTTON_STYLE_ICON, "XFDASHBOARD_BUTTON_STYLE_ICON", "icon" },
-			{ XFDASHBOARD_BUTTON_STYLE_BOTH, "XFDASHBOARD_BUTTON_STYLE_BOTH", "both" },
-			{ 0, NULL, NULL }
-		};
-
-		GType	g_define_type_id=g_enum_register_static(g_intern_static_string("XfdashboardButtonStyle"), values);
-		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
-	}
-
-	return(g_define_type_id__volatile);
-}
-
-
 /* enumerations from "image-content.h" */
 #include "image-content.h"
 
@@ -182,6 +157,55 @@ GType xfdashboard_image_content_loading_state_get_type(void)
 }
 
 
+/* enumerations from "label.h" */
+#include "label.h"
+
+GType xfdashboard_label_style_get_type(void)
+{
+	static volatile gsize	g_define_type_id__volatile=0;
+
+	if(g_once_init_enter(&g_define_type_id__volatile))
+	{
+		static const GEnumValue values[]=
+		{
+			{ XFDASHBOARD_LABEL_STYLE_TEXT, "XFDASHBOARD_LABEL_STYLE_TEXT", "text" },
+			{ XFDASHBOARD_LABEL_STYLE_ICON, "XFDASHBOARD_LABEL_STYLE_ICON", "icon" },
+			{ XFDASHBOARD_LABEL_STYLE_BOTH, "XFDASHBOARD_LABEL_STYLE_BOTH", "both" },
+			{ 0, NULL, NULL }
+		};
+
+		GType	g_define_type_id=g_enum_register_static(g_intern_static_string("XfdashboardLabelStyle"), values);
+		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+	}
+
+	return(g_define_type_id__volatile);
+}
+
+
+/* enumerations from "live-window-simple.h" */
+#include "live-window-simple.h"
+
+GType xfdashboard_live_window_simple_display_type_get_type(void)
+{
+	static volatile gsize	g_define_type_id__volatile=0;
+
+	if(g_once_init_enter(&g_define_type_id__volatile))
+	{
+		static const GEnumValue values[]=
+		{
+			{ XFDASHBOARD_LIVE_WINDOW_SIMPLE_DISPLAY_TYPE_LIVE_PREVIEW, "XFDASHBOARD_LIVE_WINDOW_SIMPLE_DISPLAY_TYPE_LIVE_PREVIEW", "live-preview" },
+			{ XFDASHBOARD_LIVE_WINDOW_SIMPLE_DISPLAY_TYPE_ICON, "XFDASHBOARD_LIVE_WINDOW_SIMPLE_DISPLAY_TYPE_ICON", "icon" },
+			{ 0, NULL, NULL }
+		};
+
+		GType	g_define_type_id=g_enum_register_static(g_intern_static_string("XfdashboardLiveWindowSimpleDisplayType"), values);
+		g_once_init_leave(&g_define_type_id__volatile, g_define_type_id);
+	}
+
+	return(g_define_type_id__volatile);
+}
+
+
 /* enumerations from "plugin.h" */
 #include "plugin.h"
 
