@@ -4,7 +4,7 @@
 /*
  * enums: Definitions of enumerations and flags used in GObject objects
  * 
- * Copyrigt 2012-2016 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,14 +47,18 @@ GType xfdashboard_binding_flags_get_type(void) G_GNUC_CONST;
 GType xfdashboard_bindings_pool_error_enum_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_BINDINGS_POOL_ERROR_ENUM	(xfdashboard_bindings_pool_error_enum_get_type())
 
-/* enumerations from "button.h" */
-GType xfdashboard_button_style_get_type(void) G_GNUC_CONST;
-#define XFDASHBOARD_TYPE_BUTTON_STYLE	(xfdashboard_button_style_get_type())
-
 /* enumerations from "image-content.h" */
 GType xfdashboard_image_content_loading_state_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_IMAGE_CONTENT_LOADING_STATE	(xfdashboard_image_content_loading_state_get_type())
 
+/* enumerations from "label.h" */
+GType xfdashboard_label_style_get_type(void) G_GNUC_CONST;
+#define XFDASHBOARD_TYPE_LABEL_STYLE	(xfdashboard_label_style_get_type())
+
+/* enumerations from "live-window-simple.h" */
+GType xfdashboard_live_window_simple_display_type_get_type(void) G_GNUC_CONST;
+#define XFDASHBOARD_TYPE_LIVE_WINDOW_SIMPLE_DISPLAY_TYPE	(xfdashboard_live_window_simple_display_type_get_type())
+
 /* enumerations from "plugin.h" */
 GType xfdashboard_plugin_flag_get_type(void) G_GNUC_CONST;
 #define XFDASHBOARD_TYPE_PLUGIN_FLAG	(xfdashboard_plugin_flag_get_type())
