@@ -6,7 +6,7 @@
  *                        within versions. We only need to use #ifdefs in
  *                        window tracker object and nowhere else in the code.
  * 
- * Copyright 2012-2016 Stephan Haller <nomad@froevel.de>
+ * Copyright 2012-2017 Stephan Haller <nomad@froevel.de>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -401,28 +401,6 @@ gboolean xfdashboard_window_tracker_window_is_visible(XfdashboardWindowTrackerWi
 	return(TRUE);
 }
 
-gboolean xfdashboard_window_tracker_window_is_visible_on_workspace(XfdashboardWindowTrackerWindow *inWindow,
-																	XfdashboardWindowTrackerWorkspace *inWorkspace)
-{
-	g_return_val_if_fail(WNCK_IS_WINDOW(inWindow), FALSE);
-	g_return_val_if_fail(WNCK_IS_WORKSPACE(inWorkspace), FALSE);
-
-	/* Check if window is visible generally and if it is on requested workspace */
-	return(xfdashboard_window_tracker_window_is_visible(inWindow) &&
-			wnck_window_is_on_workspace(WNCK_WINDOW(inWindow), WNCK_WORKSPACE(inWorkspace)));
-}
-
-gboolean xfdashboard_window_tracker_window_is_visible_on_monitor(XfdashboardWindowTrackerWindow *inWindow,
-																	XfdashboardWindowTrackerMonitor *inMonitor)
-{
-	g_return_val_if_fail(WNCK_IS_WINDOW(inWindow), FALSE);
-	g_return_val_if_fail(XFDASHBOARD_IS_WINDOW_TRACKER_MONITOR(inMonitor), FALSE);
-
-	/* Check if window is visible generally and if it is on requested monitor */
-	return(xfdashboard_window_tracker_window_is_visible(inWindow) &&
-			xfdashboard_window_tracker_window_is_on_monitor(inWindow, inMonitor));
-}
-
 /* Set visibility of window (show/hide) */
 void xfdashboard_window_tracker_window_show(XfdashboardWindowTrackerWindow *inWindow)
 {
@@ -438,6 +416,14 @@ void xfdashboard_window_tracker_window_hide(XfdashboardWindowTrackerWindow *inWi
 	wnck_window_minimize(WNCK_WINDOW(inWindow));
 }
 
+/* Get parent window if this window is a child window */
+XfdashboardWindowTrackerWindow* xfdashboard_window_tracker_window_get_parent_window(XfdashboardWindowTrackerWindow *inWindow)
+{
+	g_return_val_if_fail(WNCK_IS_WINDOW(inWindow), NULL);
+
+	return(wnck_window_get_transient(WNCK_WINDOW(inWindow)));
+}
+
 /* Get workspace where window is on */
 XfdashboardWindowTrackerWorkspace* xfdashboard_window_tracker_window_get_workspace(XfdashboardWindowTrackerWindow *inWindow)
 {
